"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatSidebarPreview = void 0;
const react_1 = require("@chakra-ui/react");
const router_1 = require("next/router");
const react_2 = __importDefault(require("react"));
const useChat_1 = require("../../hooks/useChat");
const useChatKeyFromIdentifier_1 = require("../../hooks/useChatKeyFromIdentifier");
const routes_1 = require("../../routes");
const MyFlex_1 = require("../MyFlex");
function ChatSidebarPreview({ identifier, onClick }) {
    const { chatKey, loading: loadingId } = (0, useChatKeyFromIdentifier_1.useChatKeyFromIdentifier)(identifier);
    const { info: chat, loading: loadingChat } = (0, useChat_1.useChat)(chatKey);
    const loading = loadingId || loadingChat;
    const { colorMode } = (0, react_1.useColorMode)();
    const router = (0, router_1.useRouter)();
    const { id } = router.query;
    const highlightedBg = (0, react_1.useColorModeValue)("gray.200", "gray.800");
    const subtext = (0, react_1.useColorModeValue)("gray.500", "gray.400");
    //push to url for specific chat
    const handleClick = () => {
        onClick && onClick();
        router.push((0, routes_1.route)(routes_1.routes.chat, { id: identifier }), undefined, {
            shallow: true,
        });
    };
    return (react_2.default.createElement(MyFlex_1.Flex, { overflow: "none", minW: "200px", align: "center", bg: identifier === id ? highlightedBg : undefined, px: 4, py: 3, cursor: "pointer", borderRadius: "10px", _hover: { bg: colorMode === "light" ? "gray.200" : "gray.700" }, onClick: handleClick },
        loading ? (react_2.default.createElement(react_1.SkeletonCircle, { mr: 2 })) : (react_2.default.createElement(react_1.Avatar, { mr: 2, size: "md", src: chat === null || chat === void 0 ? void 0 : chat.imageUrl })),
        loading ? (react_2.default.createElement(react_1.SkeletonText, { width: "200px" })) : (react_2.default.createElement(react_1.VStack, { spacing: 0, align: "start" },
            react_2.default.createElement(react_1.Text, { fontSize: "md", _dark: { color: "white" } }, chat === null || chat === void 0 ? void 0 : chat.name),
            react_2.default.createElement(react_1.Text, { fontSize: "sm", color: subtext },
                identifier,
                ".chat")))));
}
exports.ChatSidebarPreview = ChatSidebarPreview;
//# sourceMappingURL=ChatSidebarPreview.js.map