"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMessages = void 0;
const chat_1 = require("@strata-foundation/chat");
const react_1 = require("@strata-foundation/react");
const react_2 = require("react");
const contexts_1 = require("../contexts");
const emptyTx = new Set();
function getMessages(chat, chatSdk, txs, prevMessages) {
    return __awaiter(this, void 0, void 0, function* () {
        if (chatSdk && txs) {
            const completedMessages = (prevMessages || []).filter((msg) => !msg.pending);
            const failedTx = new Set(Array.from(txs.filter((tx) => { var _a; return (_a = tx.meta) === null || _a === void 0 ? void 0 : _a.err; }).map((tx) => tx.signature)));
            const completedTxs = new Set([
                ...Array.from((completedMessages || []).map((msg) => msg.txids).flat()),
                ...emptyTx,
            ]);
            const newTxs = txs.filter((tx) => !completedTxs.has(tx.signature));
            if (newTxs.length > 0) {
                const newParts = (yield Promise.all(newTxs.map(({ signature: sig, transaction, pending, meta, blockTime, }) => __awaiter(this, void 0, void 0, function* () {
                    let found;
                    try {
                        found = (yield chatSdk.getMessagePartsFromInflatedTx({
                            transaction: transaction,
                            txid: sig,
                            meta,
                            blockTime,
                            chat
                        })).map((f) => (Object.assign(Object.assign({}, f), { pending })));
                    }
                    catch (e) {
                        console.warn("Failed to decode message", e);
                    }
                    if (!found || (found && found.length == 0)) {
                        emptyTx.add(sig);
                    }
                    return found;
                }))))
                    .flat()
                    .filter(react_1.truthy);
                return [
                    ...(completedMessages || []),
                    ...(yield chatSdk.getMessagesFromParts(newParts)),
                ]
                    .filter((msg) => msg.txids.every((txid) => !failedTx.has(txid)))
                    .sort((a, b) => b.startBlockTime - a.startBlockTime)
                    .map((message) => {
                    // @ts-ignore
                    message.pending = message.parts.some((p) => p.pending);
                    return message;
                });
            }
            else {
                return prevMessages || [];
            }
        }
        return [];
    });
}
// Only change the identity of message.reacts if the number of reacts has increased on a message
// chat -> message id -> number of reacts
let cachedReacts = {};
function useMessages(chat, accelerated = true, numTransactions = 50) {
    const { chatSdk } = (0, contexts_1.useChatSdk)();
    const _a = (0, react_1.useTransactions)({
        address: chat,
        numTransactions,
        subscribe: true,
        accelerated,
    }), { transactions } = _a, rest = __rest(_a, ["transactions"]);
    const [{ loading, messages }, setState] = (0, react_2.useState)({
        messages: undefined,
        loading: false
    });
    const [error, setError] = (0, react_2.useState)();
    (0, react_2.useEffect)(() => {
        setState({
            loading: true,
            messages: []
        });
    }, [chat === null || chat === void 0 ? void 0 : chat.toBase58(), setState]);
    (0, react_2.useEffect)(() => {
        (() => __awaiter(this, void 0, void 0, function* () {
            if (!rest.loadingInitial && chat) {
                try {
                    const newMessages = yield getMessages(chat, chatSdk, transactions, messages);
                    setState({
                        loading: false,
                        messages: newMessages,
                    });
                }
                catch (e) {
                    setError(e);
                    setState({
                        loading: false,
                        messages: [],
                    });
                }
            }
        }))();
    }, [chat, chatSdk, transactions, setState, rest.loadingInitial]);
    // Group by and pull off reaction and reply messages
    const messagesWithReactsAndReplies = (0, react_2.useMemo)(() => {
        if (!messages) {
            return undefined;
        }
        const reacts = messages.reduce((acc, msg) => {
            if (msg && msg.type === chat_1.MessageType.React && msg.referenceMessageId) {
                if (!acc[msg.referenceMessageId]) {
                    acc[msg.referenceMessageId] = [];
                }
                acc[msg.referenceMessageId].push(msg);
            }
            return acc;
        }, {});
        const messagesById = messages.reduce((acc, msg) => {
            if (msg && msg.type !== chat_1.MessageType.React) {
                if (!acc[msg.id]) {
                    acc[msg.id] = msg;
                }
            }
            return acc;
        }, {});
        // Don't change identity of reacts array if the number of reacts has not increased
        let cachedReactsLocal = {};
        if (chat) {
            cachedReacts[chat.toBase58()] = cachedReacts[chat.toBase58()] || {};
            cachedReactsLocal = cachedReacts[chat.toBase58()];
        }
        return messages
            .filter((msg) => msg.type !== chat_1.MessageType.React)
            .map((message) => {
            var _a;
            cachedReactsLocal[message.id] = cachedReactsLocal[message.id] || [];
            if (cachedReactsLocal[message.id].length != ((_a = reacts[message.id]) === null || _a === void 0 ? void 0 : _a.length)) {
                cachedReactsLocal[message.id] = reacts[message.id];
            }
            return Object.assign(Object.assign({}, message), { reacts: cachedReactsLocal[message.id], reply: message.referenceMessageId
                    ? messagesById[message.referenceMessageId]
                    : null });
        });
    }, [chat, messages]);
    return Object.assign(Object.assign({}, rest), { loadingInitial: rest.loadingInitial || loading, error: rest.error || error, messages: messagesWithReactsAndReplies });
}
exports.useMessages = useMessages;
//# sourceMappingURL=useMessages.js.map