"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSendMessage = void 0;
const web3_js_1 = require("@solana/web3.js");
const react_1 = require("@strata-foundation/react");
const spl_utils_1 = require("@strata-foundation/spl-utils");
const react_async_hook_1 = require("react-async-hook");
const contexts_1 = require("../contexts");
const hooks_1 = require("../hooks");
const useDelegateWallet_1 = require("../hooks/useDelegateWallet");
function sendMessage({ chat, chatSdk, accelerator, delegateWalletKeypair, cluster, onAddPendingMessage, message, nftMint, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const chatKey = chat === null || chat === void 0 ? void 0 : chat.publicKey;
        if (chatSdk && chatKey) {
            const payer = (delegateWalletKeypair === null || delegateWalletKeypair === void 0 ? void 0 : delegateWalletKeypair.publicKey) || chatSdk.wallet.publicKey;
            ;
            const { instructions: instructionGroups, signers: signerGroups, output: { messageId }, } = yield chatSdk.sendMessageInstructions({
                nftMint,
                delegateWalletKeypair,
                payer,
                chat: chatKey,
                message,
                encrypted: cluster !== "localnet",
            });
            const txsAndIds = yield Promise.all(instructionGroups.map((instructions, index) => __awaiter(this, void 0, void 0, function* () {
                const tx = new web3_js_1.Transaction();
                tx.recentBlockhash = (yield chatSdk.provider.connection.getLatestBlockhash()).blockhash;
                tx.feePayer = payer;
                tx.add(...instructions);
                if (signerGroups[index].length > 0)
                    tx.sign(...signerGroups[index]);
                if (!delegateWalletKeypair) {
                    yield chatSdk.provider.wallet.signTransaction(tx);
                }
                const rawTx = tx.serialize();
                accelerator === null || accelerator === void 0 ? void 0 : accelerator.sendTransaction(cluster, tx);
                const txid = yield chatSdk.provider.connection.sendRawTransaction(rawTx, {
                    skipPreflight: true,
                });
                return {
                    txid,
                    rawTx,
                };
            })));
            const blockTime = Number((yield chatSdk.provider.connection.getAccountInfo(web3_js_1.SYSVAR_CLOCK_PUBKEY, "processed")).data.readBigInt64LE(8 * 4));
            if (onAddPendingMessage) {
                const { fileAttachments } = message, rest = __rest(message, ["fileAttachments"]);
                const content = Object.assign(Object.assign({}, rest), { decryptedAttachments: fileAttachments });
                onAddPendingMessage({
                    type: content.type,
                    sender: chatSdk.wallet.publicKey,
                    id: messageId,
                    content: JSON.stringify(content),
                    txids: txsAndIds.map(({ txid }) => txid),
                    chatKey,
                    getDecodedMessage: () => Promise.resolve(content),
                    encryptedSymmetricKey: "",
                    readPermissionAmount: chat.defaultReadPermissionAmount,
                    startBlockTime: blockTime,
                    endBlockTime: blockTime,
                    parts: [],
                    pending: true,
                    referenceMessageId: content.referenceMessageId || null,
                });
            }
            yield Promise.all(txsAndIds.map(({ rawTx }) => (0, spl_utils_1.sendAndConfirmWithRetry)(chatSdk.provider.connection, rawTx, {
                skipPreflight: true,
            }, "confirmed")));
        }
    });
}
function useSendMessage({ chatKey, onAddPendingMessage }) {
    const { chatSdk } = (0, contexts_1.useChatSdk)();
    const { accelerator } = (0, react_1.useAccelerator)();
    const { keypair: delegateWalletKeypair } = (0, useDelegateWallet_1.useDelegateWallet)();
    const { info: chat } = (0, hooks_1.useChat)(chatKey);
    const { cluster } = (0, react_1.useEndpoint)();
    const { matches } = (0, react_1.useCollectionOwnedAmount)(chat === null || chat === void 0 ? void 0 : chat.postPermissionKey);
    const { error, loading, execute, } = (0, react_async_hook_1.useAsyncCallback)(sendMessage);
    return {
        error,
        sendMessage: (message) => {
            return execute({
                chat,
                chatSdk,
                accelerator,
                delegateWalletKeypair,
                cluster,
                onAddPendingMessage,
                message,
                nftMint: matches && matches[0]
            });
        },
        loading,
    };
}
exports.useSendMessage = useSendMessage;
//# sourceMappingURL=useSendMessage.js.map